# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`splunk_hec`](#splunk_hec): Simple class to manage your splunk_hec connectivity

### Tasks

* [`bolt_apply`](#bolt_apply): This task submits the a bolt apply report (and other data) to Splunk's HEC
* [`bolt_result`](#bolt_result): This task submits a bolt task result to Splunk's HEC
* [`cleanup_tokens`](#cleanup_tokens): Revokes the tokens generated by the Splunk App Puppet Report Viewer

### Plans

* [`splunk_hec::acceptance::oss_server_setup`](#splunk_hecacceptanceoss_server_setup): Installs open source Puppet.
* [`splunk_hec::acceptance::pe_server_setup`](#splunk_hecacceptancepe_server_setup): Install PE Server
* [`splunk_hec::acceptance::provision_machines`](#splunk_hecacceptanceprovision_machines): Provisions machines
* [`splunk_hec::acceptance::server_setup`](#splunk_hecacceptanceserver_setup): Install PE Server
* [`splunk_hec::apply_example`](#splunk_hecapply_example): Example of submitting the report from a bolt apply block to Splunk users PE for pcp/hosts
* [`splunk_hec::result_example`](#splunk_hecresult_example): An example of submitting an a task or functions results to splunk as a task itself uses pcp/pe hosts

## Classes

### <a name="splunk_hec"></a>`splunk_hec`

Simple class to manage your splunk_hec connectivity

* **Note** If you manage enable_reports, it will default to puppetdb,splunk_hec
If you wish to add other reports, you can do so with the reports param
That you can have the module automatically add the splunk_hec reports
processor by setting reports to '', the empty string.

#### Examples

##### 

```puppet
include splunk_hec
```

#### Parameters

The following parameters are available in the `splunk_hec` class:

* [`url`](#url)
* [`token`](#token)
* [`collect_facts`](#collect_facts)
* [`enable_reports`](#enable_reports)
* [`record_event`](#record_event)
* [`disabled`](#disabled)
* [`manage_routes`](#manage_routes)
* [`events_reporting_enabled`](#events_reporting_enabled)
* [`facts_terminus`](#facts_terminus)
* [`facts_cache_terminus`](#facts_cache_terminus)
* [`reports`](#reports)
* [`pe_console`](#pe_console)
* [`timeout`](#timeout)
* [`ssl_ca`](#ssl_ca)
* [`ignore_system_cert_store`](#ignore_system_cert_store)
* [`token_summary`](#token_summary)
* [`token_facts`](#token_facts)
* [`token_metrics`](#token_metrics)
* [`url_summary`](#url_summary)
* [`url_facts`](#url_facts)
* [`url_metrics`](#url_metrics)
* [`include_logs_status`](#include_logs_status)
* [`include_logs_catalog_failure`](#include_logs_catalog_failure)
* [`include_logs_corrective_change`](#include_logs_corrective_change)
* [`include_resources_status`](#include_resources_status)
* [`include_resources_corrective_change`](#include_resources_corrective_change)
* [`summary_resources_format`](#summary_resources_format)
* [`event_types`](#event_types)
* [`orchestrator_data_filter`](#orchestrator_data_filter)
* [`rbac_data_filter`](#rbac_data_filter)
* [`classifier_data_filter`](#classifier_data_filter)
* [`pe_console_data_filter`](#pe_console_data_filter)
* [`code_manager_data_filter`](#code_manager_data_filter)

##### <a name="url"></a>`url`

Data type: `String`

The url of the server that PE is running on

##### <a name="token"></a>`token`

Data type: `String`

The user token

##### <a name="collect_facts"></a>`collect_facts`

Data type: `Array`

The list of facts that will be collected in the report

Default value: `['dmi','disks','partitions','processors','networking']`

##### <a name="enable_reports"></a>`enable_reports`

Data type: `Boolean`

Adds splunk_hec to the list of report processors

Default value: ``false``

##### <a name="record_event"></a>`record_event`

Data type: `Boolean`

If set to true, will call store_event and save report as json

Default value: ``false``

##### <a name="disabled"></a>`disabled`

Data type: `Boolean`

Disables the splunk_hec report processor

Default value: ``false``

##### <a name="manage_routes"></a>`manage_routes`

Data type: `Boolean`

When false, will not automatically send facts to splunk_hec

Default value: ``false``

##### <a name="events_reporting_enabled"></a>`events_reporting_enabled`

Data type: `Boolean`

When true, will send data from PE Event Forwarding module to Splunk

Default value: ``false``

##### <a name="facts_terminus"></a>`facts_terminus`

Data type: `String`

Ensure that facts get saved to puppetdb

Default value: `'puppetdb'`

##### <a name="facts_cache_terminus"></a>`facts_cache_terminus`

Data type: `String`

Makes sure that the facts get sent to splunk_hec

Default value: `'splunk_hec'`

##### <a name="reports"></a>`reports`

Data type: `Optional[String]`

Can specify report processors (other than puppetdb which is default)
Deprecated; should not use (will give warning).

Default value: ``undef``

##### <a name="pe_console"></a>`pe_console`

Data type: `Optional[String]`

The FQDN for the PE console

Default value: `$settings::report_server`

##### <a name="timeout"></a>`timeout`

Data type: `Optional[Integer]`

Timeout limit for for both open and read sessions

Default value: ``undef``

##### <a name="ssl_ca"></a>`ssl_ca`

Data type: `Optional[String]`

The name of the ca certification/bundle for ssl validation of the splunk_hec endpoint

Default value: ``undef``

##### <a name="ignore_system_cert_store"></a>`ignore_system_cert_store`

Data type: `Optional[Boolean]`

By default, the certificate provided to the ssl_ca parameter is a supplement
to the system ca certificate store. If that cert store contains invalid
certificates, ssl validation could fail. Set this parameter to true to
ignore those certificates and use only the provided file.

Default value: ``false``

##### <a name="token_summary"></a>`token_summary`

Data type: `Optional[String]`

Corresponds to puppet:summary in the Puppet Report Viewer
When storing summary in a different index than the default token

Default value: ``undef``

##### <a name="token_facts"></a>`token_facts`

Data type: `Optional[String]`

Corresponds to puppet:facts in the Puppet Report Viewer
When storing facts in a different index than the default token

Default value: ``undef``

##### <a name="token_metrics"></a>`token_metrics`

Data type: `Optional[String]`

Corresponds to puppet:metrics in the Puppet Report Viewer
When storing metrics in a different index than the default token

Default value: ``undef``

##### <a name="url_summary"></a>`url_summary`

Data type: `Optional[String]`

Similar to token_summary; used to store summary in a different index than the default url

Default value: ``undef``

##### <a name="url_facts"></a>`url_facts`

Data type: `Optional[String]`

Similar to token_facts; used to store facts in a different index than the default url

Default value: ``undef``

##### <a name="url_metrics"></a>`url_metrics`

Data type: `Optional[String]`

Similar to token_metrics; used to store metrics in a different index than the default url

Default value: ``undef``

##### <a name="include_logs_status"></a>`include_logs_status`

Data type: `Optional[Array]`

Determines if puppet logs should be included based on the return status of the puppet agent run
Can be none, one, or any of the following: failed, changed, unchanged

Default value: ``undef``

##### <a name="include_logs_catalog_failure"></a>`include_logs_catalog_failure`

Data type: `Optional[Boolean]`

Include logs if catalog fails to compile

Default value: ``false``

##### <a name="include_logs_corrective_change"></a>`include_logs_corrective_change`

Data type: `Optional[Boolean]`

Include logs if there is a corrective change
Only a PE feature

Default value: ``false``

##### <a name="include_resources_status"></a>`include_resources_status`

Data type: `Optional[Array]`

Determines if resource events should be included based on return status of puppet agent run
Does not include 'unchanged' status reports
Allowed values are: failed, changed, unchanged

Default value: ``undef``

##### <a name="include_resources_corrective_change"></a>`include_resources_corrective_change`

Data type: `Optional[Boolean]`

Include resource events if there is a corrective change
Only a PE feature

Default value: ``false``

##### <a name="summary_resources_format"></a>`summary_resources_format`

Data type: `String`

If include_resource_corrective_change or include_resources_status is set and thus resource_events
are being sent as part of puppet:summary events, then can choose format.
Allowed values are: 'hash', 'array'

Default value: `'hash'`

##### <a name="event_types"></a>`event_types`

Data type: `Optional[Array]`

Determines which events should be forwarded to Splunk
Allowed values are: 'orchestrator','rbac','classifier','pe-console','code-manager'

Default value: `['orchestrator','rbac','classifier','pe-console','code-manager']`

##### <a name="orchestrator_data_filter"></a>`orchestrator_data_filter`

Data type: `Optional[Array]`

Filters the jobs event data

Default value: ``undef``

##### <a name="rbac_data_filter"></a>`rbac_data_filter`

Data type: `Optional[Array]`

Filters the rbac event data

Default value: ``undef``

##### <a name="classifier_data_filter"></a>`classifier_data_filter`

Data type: `Optional[Array]`

Filters the classifier event data

Default value: ``undef``

##### <a name="pe_console_data_filter"></a>`pe_console_data_filter`

Data type: `Optional[Array]`

Filters the pe_console event data

Default value: ``undef``

##### <a name="code_manager_data_filter"></a>`code_manager_data_filter`

Data type: `Optional[Array]`

Filters the code_manager event data

Default value: ``undef``

## Tasks

### <a name="bolt_apply"></a>`bolt_apply`

This task submits the a bolt apply report (and other data) to Splunk's HEC

**Supports noop?** false

#### Parameters

##### `report`

Data type: `Hash`

A hash of the report, the bulk of this will be used for the splunk event

##### `facts`

Data type: `Hash`

A hash of facts, name => value

##### `host`

Data type: `Optional[String[1]]`

Target's Identifying name, will use clientcert from facts if not provided

##### `plan_guid`

Data type: `Optional[String[1]]`

A guid used to identify invocation of the plan (should change each run)

##### `plan_name`

Data type: `Optional[String[1]]`

The name of the plan being run (shouldn't change each run)

### <a name="bolt_result"></a>`bolt_result`

This task submits a bolt task result to Splunk's HEC

**Supports noop?** false

#### Parameters

##### `result`

Data type: `Hash`

The individual result from a result set

### <a name="cleanup_tokens"></a>`cleanup_tokens`

Revokes the tokens generated by the Splunk App Puppet Report Viewer

**Supports noop?** false

#### Parameters

##### `username`

Data type: `String`

Username configured in Puppet Report Viewer

## Plans

### <a name="splunk_hecacceptanceoss_server_setup"></a>`splunk_hec::acceptance::oss_server_setup`

This plan installs open source Puppet adds Puppet to the path variable, and
adds a puppet hosts entry. It also restarts the Puppet service and starts a
puppet agent run.

#### Parameters

The following parameters are available in the `splunk_hec::acceptance::oss_server_setup` plan:

* [`collection`](#collection)

##### <a name="collection"></a>`collection`

Data type: `Optional[String]`

puppet version collection name

Default value: `'puppet7'`

### <a name="splunk_hecacceptancepe_server_setup"></a>`splunk_hec::acceptance::pe_server_setup`

Install PE Server

#### Examples

##### 

```puppet
pe_event_forwarding::acceptance::pe_server_setup
```

#### Parameters

The following parameters are available in the `splunk_hec::acceptance::pe_server_setup` plan:

* [`version`](#version)
* [`pe_settings`](#pe_settings)

##### <a name="version"></a>`version`

Data type: `Optional[String]`

Sets the version of the PE to install

Default value: `'2019.8.7'`

##### <a name="pe_settings"></a>`pe_settings`

Data type: `Optional[Hash]`

Sets PE settings including password

Default value: `{password => 'puppetlabs'}`

### <a name="splunk_hecacceptanceprovision_machines"></a>`splunk_hec::acceptance::provision_machines`

Provisions machines

#### Parameters

The following parameters are available in the `splunk_hec::acceptance::provision_machines` plan:

* [`using`](#using)
* [`image`](#image)

##### <a name="using"></a>`using`

Data type: `Optional[String]`

provision service

Default value: `'abs'`

##### <a name="image"></a>`image`

Data type: `Optional[String]`

os image

Default value: `'centos-7-x86_64'`

### <a name="splunk_hecacceptanceserver_setup"></a>`splunk_hec::acceptance::server_setup`

Install PE Server

#### Examples

##### 

```puppet
pe_event_forwarding::acceptance::pe_server
```

#### Parameters

The following parameters are available in the `splunk_hec::acceptance::server_setup` plan:

* [`puppet_version`](#puppet_version)

##### <a name="puppet_version"></a>`puppet_version`

Data type: `Optional[String]`

Sets the version of Puppet Server to install

Default value: `'2019.8.7'`

### <a name="splunk_hecapply_example"></a>`splunk_hec::apply_example`

Example of submitting the report from a bolt apply block to Splunk users PE for pcp/hosts

#### Parameters

The following parameters are available in the `splunk_hec::apply_example` plan:

* [`plan_guid`](#plan_guid)
* [`plan_name`](#plan_name)

##### <a name="plan_guid"></a>`plan_guid`

Data type: `Optional[String[1]]`

A guid used to identify invocation of the plan (should change each run)

##### <a name="plan_name"></a>`plan_name`

Data type: `Optional[String[1]]`

The name of the plan being run (shouldn't change each run)

### <a name="splunk_hecresult_example"></a>`splunk_hec::result_example`

An example of submitting an a task or functions results to splunk as a task itself uses pcp/pe hosts

